# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/node_pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/node_pool.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17gateway/node_pool.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfc\x05\n\x08NodePool\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12\x1b\n\x0emin_node_count\x18\n \x01(\x05\x42\x03\xe0\x41\x01\x12\x1b\n\x0emax_node_count\x18\x0b \x01(\x05\x42\x03\xe0\x41\x01\x12%\n\x18overprovision_node_count\x18\x0c \x01(\x05\x42\x03\xe0\x41\x01\x12-\n\rgke_node_pool\x18\x02 \x01(\x0b\x32\x14.gateway.GkeNodePoolH\x00\x12-\n\reks_node_pool\x18\x07 \x01(\x0b\x32\x14.gateway.EksNodePoolH\x00\x12/\n\x0e\x66\x61ke_node_pool\x18\x03 \x01(\x0b\x32\x15.gateway.FakeNodePoolH\x00\x12\x37\n\x12minikube_node_pool\x18\x04 \x01(\x0b\x32\x19.gateway.MinikubeNodePoolH\x00\x12<\n\x0b\x61nnotations\x18\x0e \x03(\x0b\x32\".gateway.NodePool.AnnotationsEntryB\x03\xe0\x41\x01\x12.\n\x05state\x18\x05 \x01(\x0e\x32\x17.gateway.NodePool.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12-\n\x05stats\x18\r \x01(\x0b\x32\x16.gateway.NodePoolStatsB\x06\xe0\x41\x03\xe0\x41\x05\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x10\n\x0enode_pool_type\"\xdd\x01\n\x0bGkeNodePool\x12\x1c\n\x0cmachine_type\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12 \n\x10\x61\x63\x63\x65lerator_type\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11\x61\x63\x63\x65lerator_count\x18\x05 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04spot\x18\x06 \x01(\x08\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fservice_account\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04zone\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1e\n\x0enode_pool_name\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"\xf2\x01\n\x0b\x45ksNodePool\x12\x19\n\tnode_role\x18\x01 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rinstance_type\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x14\n\x04spot\x18\x04 \x01(\x08\x42\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fnode_group_name\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1a\n\nsubnet_ids\x18\x06 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x14\n\x04zone\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0fplacement_group\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0flaunch_template\x18\t \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"P\n\x0c\x46\x61keNodePool\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\x12\x11\n\tnum_nodes\x18\x02 \x01(\x05\x12\x17\n\x0fservice_account\x18\x03 \x01(\t\"\x12\n\x10MinikubeNodePool\"\xe5\x02\n\rNodePoolStats\x12\x12\n\nnode_count\x18\x01 \x01(\x05\x12\x16\n\x0eranks_per_node\x18\x02 \x01(\x05\x12\x19\n\x11\x65nvironment_count\x18\x03 \x01(\x05\x12\x19\n\x11\x65nvironment_ranks\x18\x04 \x01(\x05\x12\x42\n\x0f\x62\x61tch_job_count\x18\x05 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobCountEntry\x12\x42\n\x0f\x62\x61tch_job_ranks\x18\x06 \x03(\x0b\x32).gateway.NodePoolStats.BatchJobRanksEntry\x1a\x34\n\x12\x42\x61tchJobCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x34\n\x12\x42\x61tchJobRanksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"r\n\x15\x43reateNodePoolRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12)\n\tnode_pool\x18\x02 \x01(\x0b\x32\x11.gateway.NodePoolB\x03\xe0\x41\x02\x12\x19\n\x0cnode_pool_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\'\n\x12GetNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"-\n\x18ReconcileNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListNodePoolsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"k\n\x15ListNodePoolsResponse\x12%\n\nnode_pools\x18\x01 \x03(\x0b\x32\x11.gateway.NodePool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"B\n\x15UpdateNodePoolRequest\x12)\n\tnode_pool\x18\x01 \x01(\x0b\x32\x11.gateway.NodePoolB\x03\xe0\x41\x02\"*\n\x15\x44\x65leteNodePoolRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"F\n\x1b\x42\x61tchDeleteNodePoolsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05names\x18\x02 \x03(\tB\x03\xe0\x41\x02\",\n\x17GetNodePoolStatsRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_NODEPOOL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.NodePool.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=790,
  serialized_end=871,
)
_sym_db.RegisterEnumDescriptor(_NODEPOOL_STATE)


_NODEPOOL_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='gateway.NodePool.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.NodePool.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.NodePool.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=788,
)

_NODEPOOL = _descriptor.Descriptor(
  name='NodePool',
  full_name='gateway.NodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.NodePool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.NodePool.display_name', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.NodePool.create_time', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_node_count', full_name='gateway.NodePool.min_node_count', index=3,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_node_count', full_name='gateway.NodePool.max_node_count', index=4,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overprovision_node_count', full_name='gateway.NodePool.overprovision_node_count', index=5,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gke_node_pool', full_name='gateway.NodePool.gke_node_pool', index=6,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eks_node_pool', full_name='gateway.NodePool.eks_node_pool', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fake_node_pool', full_name='gateway.NodePool.fake_node_pool', index=8,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minikube_node_pool', full_name='gateway.NodePool.minikube_node_pool', index=9,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='gateway.NodePool.annotations', index=10,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.NodePool.state', index=11,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.NodePool.status', index=12,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='gateway.NodePool.stats', index=13,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODEPOOL_ANNOTATIONSENTRY, ],
  enum_types=[
    _NODEPOOL_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node_pool_type', full_name='gateway.NodePool.node_pool_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=125,
  serialized_end=889,
)


_GKENODEPOOL = _descriptor.Descriptor(
  name='GkeNodePool',
  full_name='gateway.GkeNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_type', full_name='gateway.GkeNodePool.machine_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerator_type', full_name='gateway.GkeNodePool.accelerator_type', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerator_count', full_name='gateway.GkeNodePool.accelerator_count', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot', full_name='gateway.GkeNodePool.spot', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account', full_name='gateway.GkeNodePool.service_account', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='gateway.GkeNodePool.zone', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool_name', full_name='gateway.GkeNodePool.node_pool_name', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=1113,
)


_EKSNODEPOOL = _descriptor.Descriptor(
  name='EksNodePool',
  full_name='gateway.EksNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_role', full_name='gateway.EksNodePool.node_role', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='gateway.EksNodePool.instance_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot', full_name='gateway.EksNodePool.spot', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_group_name', full_name='gateway.EksNodePool.node_group_name', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_ids', full_name='gateway.EksNodePool.subnet_ids', index=4,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='gateway.EksNodePool.zone', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group', full_name='gateway.EksNodePool.placement_group', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='launch_template', full_name='gateway.EksNodePool.launch_template', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1116,
  serialized_end=1358,
)


_FAKENODEPOOL = _descriptor.Descriptor(
  name='FakeNodePool',
  full_name='gateway.FakeNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machine_type', full_name='gateway.FakeNodePool.machine_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_nodes', full_name='gateway.FakeNodePool.num_nodes', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account', full_name='gateway.FakeNodePool.service_account', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1360,
  serialized_end=1440,
)


_MINIKUBENODEPOOL = _descriptor.Descriptor(
  name='MinikubeNodePool',
  full_name='gateway.MinikubeNodePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1460,
)


_NODEPOOLSTATS_BATCHJOBCOUNTENTRY = _descriptor.Descriptor(
  name='BatchJobCountEntry',
  full_name='gateway.NodePoolStats.BatchJobCountEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.NodePoolStats.BatchJobCountEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.NodePoolStats.BatchJobCountEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1766,
)

_NODEPOOLSTATS_BATCHJOBRANKSENTRY = _descriptor.Descriptor(
  name='BatchJobRanksEntry',
  full_name='gateway.NodePoolStats.BatchJobRanksEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.NodePoolStats.BatchJobRanksEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.NodePoolStats.BatchJobRanksEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1768,
  serialized_end=1820,
)

_NODEPOOLSTATS = _descriptor.Descriptor(
  name='NodePoolStats',
  full_name='gateway.NodePoolStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_count', full_name='gateway.NodePoolStats.node_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ranks_per_node', full_name='gateway.NodePoolStats.ranks_per_node', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment_count', full_name='gateway.NodePoolStats.environment_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment_ranks', full_name='gateway.NodePoolStats.environment_ranks', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_job_count', full_name='gateway.NodePoolStats.batch_job_count', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_job_ranks', full_name='gateway.NodePoolStats.batch_job_ranks', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODEPOOLSTATS_BATCHJOBCOUNTENTRY, _NODEPOOLSTATS_BATCHJOBRANKSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1820,
)


_CREATENODEPOOLREQUEST = _descriptor.Descriptor(
  name='CreateNodePoolRequest',
  full_name='gateway.CreateNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateNodePoolRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool', full_name='gateway.CreateNodePoolRequest.node_pool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_pool_id', full_name='gateway.CreateNodePoolRequest.node_pool_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1936,
)


_GETNODEPOOLREQUEST = _descriptor.Descriptor(
  name='GetNodePoolRequest',
  full_name='gateway.GetNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetNodePoolRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=1977,
)


_RECONCILENODEPOOLREQUEST = _descriptor.Descriptor(
  name='ReconcileNodePoolRequest',
  full_name='gateway.ReconcileNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.ReconcileNodePoolRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1979,
  serialized_end=2024,
)


_LISTNODEPOOLSREQUEST = _descriptor.Descriptor(
  name='ListNodePoolsRequest',
  full_name='gateway.ListNodePoolsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListNodePoolsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListNodePoolsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListNodePoolsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListNodePoolsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListNodePoolsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2027,
  serialized_end=2163,
)


_LISTNODEPOOLSRESPONSE = _descriptor.Descriptor(
  name='ListNodePoolsResponse',
  full_name='gateway.ListNodePoolsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pools', full_name='gateway.ListNodePoolsResponse.node_pools', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListNodePoolsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListNodePoolsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2165,
  serialized_end=2272,
)


_UPDATENODEPOOLREQUEST = _descriptor.Descriptor(
  name='UpdateNodePoolRequest',
  full_name='gateway.UpdateNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_pool', full_name='gateway.UpdateNodePoolRequest.node_pool', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2274,
  serialized_end=2340,
)


_DELETENODEPOOLREQUEST = _descriptor.Descriptor(
  name='DeleteNodePoolRequest',
  full_name='gateway.DeleteNodePoolRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteNodePoolRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2342,
  serialized_end=2384,
)


_BATCHDELETENODEPOOLSREQUEST = _descriptor.Descriptor(
  name='BatchDeleteNodePoolsRequest',
  full_name='gateway.BatchDeleteNodePoolsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.BatchDeleteNodePoolsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='gateway.BatchDeleteNodePoolsRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2386,
  serialized_end=2456,
)


_GETNODEPOOLSTATSREQUEST = _descriptor.Descriptor(
  name='GetNodePoolStatsRequest',
  full_name='gateway.GetNodePoolStatsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetNodePoolStatsRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2458,
  serialized_end=2502,
)

_NODEPOOL_ANNOTATIONSENTRY.containing_type = _NODEPOOL
_NODEPOOL.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NODEPOOL.fields_by_name['gke_node_pool'].message_type = _GKENODEPOOL
_NODEPOOL.fields_by_name['eks_node_pool'].message_type = _EKSNODEPOOL
_NODEPOOL.fields_by_name['fake_node_pool'].message_type = _FAKENODEPOOL
_NODEPOOL.fields_by_name['minikube_node_pool'].message_type = _MINIKUBENODEPOOL
_NODEPOOL.fields_by_name['annotations'].message_type = _NODEPOOL_ANNOTATIONSENTRY
_NODEPOOL.fields_by_name['state'].enum_type = _NODEPOOL_STATE
_NODEPOOL.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_NODEPOOL.fields_by_name['stats'].message_type = _NODEPOOLSTATS
_NODEPOOL_STATE.containing_type = _NODEPOOL
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['gke_node_pool'])
_NODEPOOL.fields_by_name['gke_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['eks_node_pool'])
_NODEPOOL.fields_by_name['eks_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['fake_node_pool'])
_NODEPOOL.fields_by_name['fake_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOL.oneofs_by_name['node_pool_type'].fields.append(
  _NODEPOOL.fields_by_name['minikube_node_pool'])
_NODEPOOL.fields_by_name['minikube_node_pool'].containing_oneof = _NODEPOOL.oneofs_by_name['node_pool_type']
_NODEPOOLSTATS_BATCHJOBCOUNTENTRY.containing_type = _NODEPOOLSTATS
_NODEPOOLSTATS_BATCHJOBRANKSENTRY.containing_type = _NODEPOOLSTATS
_NODEPOOLSTATS.fields_by_name['batch_job_count'].message_type = _NODEPOOLSTATS_BATCHJOBCOUNTENTRY
_NODEPOOLSTATS.fields_by_name['batch_job_ranks'].message_type = _NODEPOOLSTATS_BATCHJOBRANKSENTRY
_CREATENODEPOOLREQUEST.fields_by_name['node_pool'].message_type = _NODEPOOL
_LISTNODEPOOLSRESPONSE.fields_by_name['node_pools'].message_type = _NODEPOOL
_UPDATENODEPOOLREQUEST.fields_by_name['node_pool'].message_type = _NODEPOOL
DESCRIPTOR.message_types_by_name['NodePool'] = _NODEPOOL
DESCRIPTOR.message_types_by_name['GkeNodePool'] = _GKENODEPOOL
DESCRIPTOR.message_types_by_name['EksNodePool'] = _EKSNODEPOOL
DESCRIPTOR.message_types_by_name['FakeNodePool'] = _FAKENODEPOOL
DESCRIPTOR.message_types_by_name['MinikubeNodePool'] = _MINIKUBENODEPOOL
DESCRIPTOR.message_types_by_name['NodePoolStats'] = _NODEPOOLSTATS
DESCRIPTOR.message_types_by_name['CreateNodePoolRequest'] = _CREATENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['GetNodePoolRequest'] = _GETNODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['ReconcileNodePoolRequest'] = _RECONCILENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['ListNodePoolsRequest'] = _LISTNODEPOOLSREQUEST
DESCRIPTOR.message_types_by_name['ListNodePoolsResponse'] = _LISTNODEPOOLSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateNodePoolRequest'] = _UPDATENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['DeleteNodePoolRequest'] = _DELETENODEPOOLREQUEST
DESCRIPTOR.message_types_by_name['BatchDeleteNodePoolsRequest'] = _BATCHDELETENODEPOOLSREQUEST
DESCRIPTOR.message_types_by_name['GetNodePoolStatsRequest'] = _GETNODEPOOLSTATSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NodePool = _reflection.GeneratedProtocolMessageType('NodePool', (_message.Message,), {

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEPOOL_ANNOTATIONSENTRY,
    '__module__' : 'gateway.node_pool_pb2'
    # @@protoc_insertion_point(class_scope:gateway.NodePool.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _NODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.NodePool)
  })
_sym_db.RegisterMessage(NodePool)
_sym_db.RegisterMessage(NodePool.AnnotationsEntry)

GkeNodePool = _reflection.GeneratedProtocolMessageType('GkeNodePool', (_message.Message,), {
  'DESCRIPTOR' : _GKENODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GkeNodePool)
  })
_sym_db.RegisterMessage(GkeNodePool)

EksNodePool = _reflection.GeneratedProtocolMessageType('EksNodePool', (_message.Message,), {
  'DESCRIPTOR' : _EKSNODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.EksNodePool)
  })
_sym_db.RegisterMessage(EksNodePool)

FakeNodePool = _reflection.GeneratedProtocolMessageType('FakeNodePool', (_message.Message,), {
  'DESCRIPTOR' : _FAKENODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.FakeNodePool)
  })
_sym_db.RegisterMessage(FakeNodePool)

MinikubeNodePool = _reflection.GeneratedProtocolMessageType('MinikubeNodePool', (_message.Message,), {
  'DESCRIPTOR' : _MINIKUBENODEPOOL,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.MinikubeNodePool)
  })
_sym_db.RegisterMessage(MinikubeNodePool)

NodePoolStats = _reflection.GeneratedProtocolMessageType('NodePoolStats', (_message.Message,), {

  'BatchJobCountEntry' : _reflection.GeneratedProtocolMessageType('BatchJobCountEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEPOOLSTATS_BATCHJOBCOUNTENTRY,
    '__module__' : 'gateway.node_pool_pb2'
    # @@protoc_insertion_point(class_scope:gateway.NodePoolStats.BatchJobCountEntry)
    })
  ,

  'BatchJobRanksEntry' : _reflection.GeneratedProtocolMessageType('BatchJobRanksEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODEPOOLSTATS_BATCHJOBRANKSENTRY,
    '__module__' : 'gateway.node_pool_pb2'
    # @@protoc_insertion_point(class_scope:gateway.NodePoolStats.BatchJobRanksEntry)
    })
  ,
  'DESCRIPTOR' : _NODEPOOLSTATS,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.NodePoolStats)
  })
_sym_db.RegisterMessage(NodePoolStats)
_sym_db.RegisterMessage(NodePoolStats.BatchJobCountEntry)
_sym_db.RegisterMessage(NodePoolStats.BatchJobRanksEntry)

CreateNodePoolRequest = _reflection.GeneratedProtocolMessageType('CreateNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateNodePoolRequest)
  })
_sym_db.RegisterMessage(CreateNodePoolRequest)

GetNodePoolRequest = _reflection.GeneratedProtocolMessageType('GetNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetNodePoolRequest)
  })
_sym_db.RegisterMessage(GetNodePoolRequest)

ReconcileNodePoolRequest = _reflection.GeneratedProtocolMessageType('ReconcileNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _RECONCILENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ReconcileNodePoolRequest)
  })
_sym_db.RegisterMessage(ReconcileNodePoolRequest)

ListNodePoolsRequest = _reflection.GeneratedProtocolMessageType('ListNodePoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEPOOLSREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListNodePoolsRequest)
  })
_sym_db.RegisterMessage(ListNodePoolsRequest)

ListNodePoolsResponse = _reflection.GeneratedProtocolMessageType('ListNodePoolsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNODEPOOLSRESPONSE,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListNodePoolsResponse)
  })
_sym_db.RegisterMessage(ListNodePoolsResponse)

UpdateNodePoolRequest = _reflection.GeneratedProtocolMessageType('UpdateNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateNodePoolRequest)
  })
_sym_db.RegisterMessage(UpdateNodePoolRequest)

DeleteNodePoolRequest = _reflection.GeneratedProtocolMessageType('DeleteNodePoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENODEPOOLREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteNodePoolRequest)
  })
_sym_db.RegisterMessage(DeleteNodePoolRequest)

BatchDeleteNodePoolsRequest = _reflection.GeneratedProtocolMessageType('BatchDeleteNodePoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHDELETENODEPOOLSREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BatchDeleteNodePoolsRequest)
  })
_sym_db.RegisterMessage(BatchDeleteNodePoolsRequest)

GetNodePoolStatsRequest = _reflection.GeneratedProtocolMessageType('GetNodePoolStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEPOOLSTATSREQUEST,
  '__module__' : 'gateway.node_pool_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetNodePoolStatsRequest)
  })
_sym_db.RegisterMessage(GetNodePoolStatsRequest)


DESCRIPTOR._options = None
_NODEPOOL_ANNOTATIONSENTRY._options = None
_NODEPOOL.fields_by_name['name']._options = None
_NODEPOOL.fields_by_name['display_name']._options = None
_NODEPOOL.fields_by_name['create_time']._options = None
_NODEPOOL.fields_by_name['min_node_count']._options = None
_NODEPOOL.fields_by_name['max_node_count']._options = None
_NODEPOOL.fields_by_name['overprovision_node_count']._options = None
_NODEPOOL.fields_by_name['annotations']._options = None
_NODEPOOL.fields_by_name['state']._options = None
_NODEPOOL.fields_by_name['status']._options = None
_NODEPOOL.fields_by_name['stats']._options = None
_GKENODEPOOL.fields_by_name['machine_type']._options = None
_GKENODEPOOL.fields_by_name['accelerator_type']._options = None
_GKENODEPOOL.fields_by_name['accelerator_count']._options = None
_GKENODEPOOL.fields_by_name['spot']._options = None
_GKENODEPOOL.fields_by_name['service_account']._options = None
_GKENODEPOOL.fields_by_name['zone']._options = None
_GKENODEPOOL.fields_by_name['node_pool_name']._options = None
_EKSNODEPOOL.fields_by_name['node_role']._options = None
_EKSNODEPOOL.fields_by_name['instance_type']._options = None
_EKSNODEPOOL.fields_by_name['spot']._options = None
_EKSNODEPOOL.fields_by_name['node_group_name']._options = None
_EKSNODEPOOL.fields_by_name['subnet_ids']._options = None
_EKSNODEPOOL.fields_by_name['zone']._options = None
_EKSNODEPOOL.fields_by_name['placement_group']._options = None
_EKSNODEPOOL.fields_by_name['launch_template']._options = None
_NODEPOOLSTATS_BATCHJOBCOUNTENTRY._options = None
_NODEPOOLSTATS_BATCHJOBRANKSENTRY._options = None
_CREATENODEPOOLREQUEST.fields_by_name['parent']._options = None
_CREATENODEPOOLREQUEST.fields_by_name['node_pool']._options = None
_CREATENODEPOOLREQUEST.fields_by_name['node_pool_id']._options = None
_GETNODEPOOLREQUEST.fields_by_name['name']._options = None
_RECONCILENODEPOOLREQUEST.fields_by_name['name']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['parent']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['page_size']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['page_token']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['filter']._options = None
_LISTNODEPOOLSREQUEST.fields_by_name['order_by']._options = None
_UPDATENODEPOOLREQUEST.fields_by_name['node_pool']._options = None
_DELETENODEPOOLREQUEST.fields_by_name['name']._options = None
_BATCHDELETENODEPOOLSREQUEST.fields_by_name['parent']._options = None
_BATCHDELETENODEPOOLSREQUEST.fields_by_name['names']._options = None
_GETNODEPOOLSTATSREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



from typing import Literal


AcceleratorTypeLiteral = Literal[
    "ACCELERATOR_TYPE_UNSPECIFIED",
    "NVIDIA_A100_80GB",
    "NVIDIA_H100_80GB",
    "AMD_MI300X_192GB",
    "NVIDIA_A10G_24GB",
    "NVIDIA_A100_40GB",
    "NVIDIA_L4_24GB",
    "NVIDIA_H200_141GB",
    "NVIDIA_B200_180GB",
]


RegionLiteral = Literal[
    "REGION_UNSPECIFIED",
    "US_IOWA_1",
    "US_VIRGINIA_1",
    "US_VIRGINIA_2",
    "US_ILLINOIS_1",
    "AP_TOKYO_1",
    "EU_LONDON_1",
    "US_ARIZONA_1",
    "US_TEXAS_1",
    "US_ILLINOIS_2",
    "EU_FRANKFURT_1",
    "US_TEXAS_2",
    "EU_PARIS_1",
    "EU_HELSINKI_1",
    "US_NEVADA_1",
    "EU_ICELAND_1",
    "EU_ICELAND_2",
    "US_WASHINGTON_1",
    "US_WASHINGTON_2",
]


ReasoningEffort = Literal["low", "medium", "high"]



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
ENUM_VISIBILITY_FIELD_NUMBER: _ClassVar[int]
enum_visibility: _descriptor.FieldDescriptor
VALUE_VISIBILITY_FIELD_NUMBER: _ClassVar[int]
value_visibility: _descriptor.FieldDescriptor
FIELD_VISIBILITY_FIELD_NUMBER: _ClassVar[int]
field_visibility: _descriptor.FieldDescriptor
MESSAGE_VISIBILITY_FIELD_NUMBER: _ClassVar[int]
message_visibility: _descriptor.FieldDescriptor
METHOD_VISIBILITY_FIELD_NUMBER: _ClassVar[int]
method_visibility: _descriptor.FieldDescriptor
API_VISIBILITY_FIELD_NUMBER: _ClassVar[int]
api_visibility: _descriptor.FieldDescriptor

class Visibility(_message.Message):
    __slots__ = ("rules",)
    RULES_FIELD_NUMBER: _ClassVar[int]
    rules: _containers.RepeatedCompositeFieldContainer[VisibilityRule]
    def __init__(self, rules: _Optional[_Iterable[_Union[VisibilityRule, _Mapping]]] = ...) -> None: ...

class VisibilityRule(_message.Message):
    __slots__ = ("selector", "restriction")
    SELECTOR_FIELD_NUMBER: _ClassVar[int]
    RESTRICTION_FIELD_NUMBER: _ClassVar[int]
    selector: str
    restriction: str
    def __init__(self, selector: _Optional[str] = ..., restriction: _Optional[str] = ...) -> None: ...



from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetOAuthArgumentsRequest(_message.Message):
    __slots__ = ("account_id",)
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    account_id: str
    def __init__(self, account_id: _Optional[str] = ...) -> None: ...

class GetOAuthArgumentsResponse(_message.Message):
    __slots__ = ("issuer_url", "client_id", "cognito_domain")
    ISSUER_URL_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    COGNITO_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    issuer_url: str
    client_id: str
    cognito_domain: str
    def __init__(self, issuer_url: _Optional[str] = ..., client_id: _Optional[str] = ..., cognito_domain: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/training.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/training.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gateway/training.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x18gateway/deployment.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\">\n\x0f\x45\x61rlyStopConfig\x12\x14\n\x06is_set\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x15\n\x07\x65nabled\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01\"\xf1\x05\n\x12\x42\x61seTrainingConfig\x12\x1a\n\x0coutput_model\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01\x12\x18\n\nbase_model\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1d\n\x0fwarm_start_from\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x1c\n\x0ejinja_template\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12*\n\rlearning_rate\x18\x05 \x01(\x02\x42\x13\xe2\x41\x01\x01\xbaH\x0c\n\n\x1d\xcd\xcc\xcc=-\x00\x00\x00\x00\x12 \n\x12max_context_length\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12 \n\tlora_rank\x18\x07 \x01(\x05\x42\r\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18 (\x00\x12Y\n\x1b\x62\x61se_model_weight_precision\x18\x08 \x01(\x0e\x32\x18.gateway.WeightPrecisionB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12N\n\x10\x61\x63\x63\x65lerator_type\x18\t \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x35\n\x11\x61\x63\x63\x65lerator_count\x18\n \x01(\x05\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12%\n\x06region\x18\x0b \x01(\x0e\x32\x0f.gateway.RegionB\x04\xe2\x41\x01\x01\x12\x1b\n\x06\x65pochs\x18\x0c \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x18\n\nbatch_size\x18\r \x01(\x05\x42\x04\xe2\x41\x01\x01:\xb7\x01\xbaH\xb3\x01\x1a\xb0\x01\n5base_training_config.exactly_one_of_must_be_specified\x12>exactly one of base_model or warm_start_from must be specified\x1a\x37(this.base_model != \'\') != (this.warm_start_from != \'\')*T\n\x0fWeightPrecision\x12 \n\x1cWEIGHT_PRECISION_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x42\x46LOAT16\x10\x01\x12\x08\n\x04INT8\x10\x02\x12\x07\n\x03NF4\x10\x03\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.training_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_EARLYSTOPCONFIG'].fields_by_name['is_set']._loaded_options = None
  _globals['_EARLYSTOPCONFIG'].fields_by_name['is_set']._serialized_options = b'\342A\001\001'
  _globals['_EARLYSTOPCONFIG'].fields_by_name['enabled']._loaded_options = None
  _globals['_EARLYSTOPCONFIG'].fields_by_name['enabled']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG'].fields_by_name['output_model']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['output_model']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG'].fields_by_name['base_model']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['base_model']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG'].fields_by_name['warm_start_from']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['warm_start_from']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG'].fields_by_name['jinja_template']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['jinja_template']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG'].fields_by_name['learning_rate']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['learning_rate']._serialized_options = b'\342A\001\001\272H\014\n\n\035\315\314\314=-\000\000\000\000'
  _globals['_BASETRAININGCONFIG'].fields_by_name['max_context_length']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['max_context_length']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG'].fields_by_name['lora_rank']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['lora_rank']._serialized_options = b'\342A\001\001\272H\006\032\004\030 (\000'
  _globals['_BASETRAININGCONFIG'].fields_by_name['base_model_weight_precision']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['base_model_weight_precision']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_BASETRAININGCONFIG'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_BASETRAININGCONFIG'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_BASETRAININGCONFIG'].fields_by_name['region']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['region']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG'].fields_by_name['epochs']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['epochs']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_BASETRAININGCONFIG'].fields_by_name['batch_size']._loaded_options = None
  _globals['_BASETRAININGCONFIG'].fields_by_name['batch_size']._serialized_options = b'\342A\001\001'
  _globals['_BASETRAININGCONFIG']._loaded_options = None
  _globals['_BASETRAININGCONFIG']._serialized_options = b'\272H\263\001\032\260\001\n5base_training_config.exactly_one_of_must_be_specified\022>exactly one of base_model or warm_start_from must be specified\0327(this.base_model != \'\') != (this.warm_start_from != \'\')'
  _globals['_WEIGHTPRECISION']._serialized_start=972
  _globals['_WEIGHTPRECISION']._serialized_end=1056
  _globals['_EARLYSTOPCONFIG']._serialized_start=152
  _globals['_EARLYSTOPCONFIG']._serialized_end=214
  _globals['_BASETRAININGCONFIG']._serialized_start=217
  _globals['_BASETRAININGCONFIG']._serialized_end=970
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google/api/annotations.proto, google/api/field_behavior.proto, google/api/http.proto, google/api/resource.proto, google/api/visibility.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "FieldBehavior",
    "ResourceDescriptorHistory",
    "ResourceDescriptorStyle",
    "ResourceDescriptor",
    "ResourceReference",
    "Visibility",
    "VisibilityRule",
    "Http",
    "HttpRule",
    "CustomHttpPattern",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto


class FieldBehavior(betterproto.Enum):
    """
    An indicator of the behavior of a given field (for example, that a field
    is required in requests, or given as output but ignored as input).
    This **does not** change the behavior in protocol buffers itself; it only
    denotes the behavior and may affect how API tooling handles the field.

    Note: This enum **may** receive new values in the future.
    """

    UNSPECIFIED = 0
    """Conventional default for enums. Do not use this."""

    OPTIONAL = 1
    """
    Specifically denotes a field as optional.
    While all fields in protocol buffers are optional, this may be specified
    for emphasis if appropriate.
    """

    REQUIRED = 2
    """
    Denotes a field as required.
    This indicates that the field **must** be provided as part of the request,
    and failure to do so will cause an error (usually `INVALID_ARGUMENT`).
    """

    OUTPUT_ONLY = 3
    """
    Denotes a field as output only.
    This indicates that the field is provided in responses, but including the
    field in a request does nothing (the server *must* ignore it and
    *must not* throw an error as a result of the field's presence).
    """

    INPUT_ONLY = 4
    """
    Denotes a field as input only.
    This indicates that the field is provided in requests, and the
    corresponding field is not included in output.
    """

    IMMUTABLE = 5
    """
    Denotes a field as immutable.
    This indicates that the field may be set once in a request to create a
    resource, but may not be changed thereafter.
    """

    UNORDERED_LIST = 6
    """
    Denotes that a (repeated) field is an unordered list.
    This indicates that the service may provide the elements of the list
    in any arbitrary  order, rather than the order the user originally
    provided. Additionally, the list's order may or may not be stable.
    """

    NON_EMPTY_DEFAULT = 7
    """
    Denotes that this field returns a non-empty default value if not set.
    This indicates that if the user provides the empty value in a request,
    a non-empty value will be returned. The user will not be aware of what
    non-empty value to expect.
    """


class ResourceDescriptorHistory(betterproto.Enum):
    """
    A description of the historical or future-looking state of the
    resource pattern.
    """

    HISTORY_UNSPECIFIED = 0
    """The "unset" value."""

    ORIGINALLY_SINGLE_PATTERN = 1
    """
    The resource originally had one pattern and launched as such, and
    additional patterns were added later.
    """

    FUTURE_MULTI_PATTERN = 2
    """
    The resource has one pattern, but the API owner expects to add more
    later. (This is the inverse of ORIGINALLY_SINGLE_PATTERN, and prevents
    that from being necessary once there are multiple patterns.)
    """


class ResourceDescriptorStyle(betterproto.Enum):
    """
    A flag representing a specific style that a resource claims to conform to.
    """

    STYLE_UNSPECIFIED = 0
    """The unspecified value. Do not use."""

    DECLARATIVE_FRIENDLY = 1
    """
    This resource is intended to be "declarative-friendly".
    
    Declarative-friendly resources must be more strictly consistent, and
    setting this to true communicates to tools that this resource should
    adhere to declarative-friendly expectations.
    
    Note: This is used by the API linter (linter.aip.dev) to enable
    additional checks.
    """


@dataclass(eq=False, repr=False)
class ResourceDescriptor(betterproto.Message):
    """
    A simple descriptor of a resource type.

    ResourceDescriptor annotates a resource message (either by means of a
    protobuf annotation or use in the service config), and associates the
    resource's schema, the resource type, and the pattern of the resource name.

    Example:

        message Topic {
          // Indicates this message defines a resource schema.
          // Declares the resource type in the format of {service}/{kind}.
          // For Kubernetes resources, the format is {api group}/{kind}.
          option (google.api.resource) = {
            type: "pubsub.googleapis.com/Topic"
            pattern: "projects/{project}/topics/{topic}"
          };
        }

    The ResourceDescriptor Yaml config will look like:

        resources:
        - type: "pubsub.googleapis.com/Topic"
          pattern: "projects/{project}/topics/{topic}"

    Sometimes, resources have multiple patterns, typically because they can
    live under multiple parents.

    Example:

        message LogEntry {
          option (google.api.resource) = {
            type: "logging.googleapis.com/LogEntry"
            pattern: "projects/{project}/logs/{log}"
            pattern: "folders/{folder}/logs/{log}"
            pattern: "organizations/{organization}/logs/{log}"
            pattern: "billingAccounts/{billing_account}/logs/{log}"
          };
        }

    The ResourceDescriptor Yaml config will look like:

        resources:
        - type: 'logging.googleapis.com/LogEntry'
          pattern: "projects/{project}/logs/{log}"
          pattern: "folders/{folder}/logs/{log}"
          pattern: "organizations/{organization}/logs/{log}"
          pattern: "billingAccounts/{billing_account}/logs/{log}"
    """

    type: str = betterproto.string_field(1)
    """
    The resource type. It must be in the format of
    {service_name}/{resource_type_kind}. The `resource_type_kind` must be
    singular and must not include version numbers.
    
    Example: `storage.googleapis.com/Bucket`
    
    The value of the resource_type_kind must follow the regular expression
    /[A-Za-z][a-zA-Z0-9]+/. It should start with an upper case character and
    should use PascalCase (UpperCamelCase). The maximum number of
    characters allowed for the `resource_type_kind` is 100.
    """

    pattern: List[str] = betterproto.string_field(2)
    """
    Optional. The relative resource name pattern associated with this resource
    type. The DNS prefix of the full resource name shouldn't be specified here.
    
    The path pattern must follow the syntax, which aligns with HTTP binding
    syntax:
    
        Template = Segment { "/" Segment } ;
        Segment = LITERAL | Variable ;
        Variable = "{" LITERAL "}" ;
    
    Examples:
    
        - "projects/{project}/topics/{topic}"
        - "projects/{project}/knowledgeBases/{knowledge_base}"
    
    The components in braces correspond to the IDs for each resource in the
    hierarchy. It is expected that, if multiple patterns are provided,
    the same component name (e.g. "project") refers to IDs of the same
    type of resource.
    """

    name_field: str = betterproto.string_field(3)
    """
    Optional. The field on the resource that designates the resource name
    field. If omitted, this is assumed to be "name".
    """

    history: "ResourceDescriptorHistory" = betterproto.enum_field(4)
    """
    Optional. The historical or future-looking state of the resource pattern.
    
    Example:
    
        // The InspectTemplate message originally only supported resource
        // names with organization, and project was added later.
        message InspectTemplate {
          option (google.api.resource) = {
            type: "dlp.googleapis.com/InspectTemplate"
            pattern:
            "organizations/{organization}/inspectTemplates/{inspect_template}"
            pattern: "projects/{project}/inspectTemplates/{inspect_template}"
            history: ORIGINALLY_SINGLE_PATTERN
          };
        }
    """

    plural: str = betterproto.string_field(5)
    """
    The plural name used in the resource name and permission names, such as
    'projects' for the resource name of 'projects/{project}' and the permission
    name of 'cloudresourcemanager.googleapis.com/projects.get'. One exception
    to this is for Nested Collections that have stuttering names, as defined
    in [AIP-122](https://google.aip.dev/122#nested-collections), where the
    collection ID in the resource name pattern does not necessarily directly
    match the `plural` value.
    
    It is the same concept of the `plural` field in k8s CRD spec
    https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions/
    
    Note: The plural form is required even for singleton resources. See
    https://aip.dev/156
    """

    singular: str = betterproto.string_field(6)
    """
    The same concept of the `singular` field in k8s CRD spec
    https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions/
    Such as "project" for the `resourcemanager.googleapis.com/Project` type.
    """

    style: List["ResourceDescriptorStyle"] = betterproto.enum_field(10)
    """
    Style flag(s) for this resource.
    These indicate that a resource is expected to conform to a given
    style. See the specific style flags for additional information.
    """


@dataclass(eq=False, repr=False)
class ResourceReference(betterproto.Message):
    """
    Defines a proto annotation that describes a string field that refers to
    an API resource.
    """

    type: str = betterproto.string_field(1)
    """
    The resource type that the annotated field references.
    
    Example:
    
        message Subscription {
          string topic = 2 [(google.api.resource_reference) = {
            type: "pubsub.googleapis.com/Topic"
          }];
        }
    
    Occasionally, a field may reference an arbitrary resource. In this case,
    APIs use the special value * in their resource reference.
    
    Example:
    
        message GetIamPolicyRequest {
          string resource = 2 [(google.api.resource_reference) = {
            type: "*"
          }];
        }
    """

    child_type: str = betterproto.string_field(2)
    """
    The resource type of a child collection that the annotated field
    references. This is useful for annotating the `parent` field that
    doesn't have a fixed resource type.
    
    Example:
    
        message ListLogEntriesRequest {
          string parent = 1 [(google.api.resource_reference) = {
            child_type: "logging.googleapis.com/LogEntry"
          };
        }
    """


@dataclass(eq=False, repr=False)
class Visibility(betterproto.Message):
    """
    `Visibility` restricts service consumer's access to service elements,
    such as whether an application can call a visibility-restricted method.
    The restriction is expressed by applying visibility labels on service
    elements. The visibility labels are elsewhere linked to service consumers.

    A service can define multiple visibility labels, but a service consumer
    should be granted at most one visibility label. Multiple visibility
    labels for a single service consumer are not supported.

    If an element and all its parents have no visibility label, its visibility
    is unconditionally granted.

    Example:

        visibility:
          rules:
          - selector: google.calendar.Calendar.EnhancedSearch
            restriction: PREVIEW
          - selector: google.calendar.Calendar.Delegate
            restriction: INTERNAL

    Here, all methods are publicly visible except for the restricted methods
    EnhancedSearch and Delegate.
    """

    rules: List["VisibilityRule"] = betterproto.message_field(1)
    """
    A list of visibility rules that apply to individual API elements.
    
    **NOTE:** All service configuration rules follow "last one wins" order.
    """


@dataclass(eq=False, repr=False)
class VisibilityRule(betterproto.Message):
    """
    A visibility rule provides visibility configuration for an individual API
    element.
    """

    selector: str = betterproto.string_field(1)
    """
    Selects methods, messages, fields, enums, etc. to which this rule
    applies.
    
    Refer to [selector][google.api.DocumentationRule.selector] for syntax
    details.
    """

    restriction: str = betterproto.string_field(2)
    """
    A comma-separated list of visibility labels that apply to the `selector`.
    Any of the listed labels can be used to grant the visibility.
    
    If a rule has multiple labels, removing one of the labels but not all of
    them can break clients.
    
    Example:
    
        visibility:
          rules:
          - selector: google.calendar.Calendar.EnhancedSearch
            restriction: INTERNAL, PREVIEW
    
    Removing INTERNAL from this restriction will break clients that rely on
    this method and only had access to it through INTERNAL.
    """


@dataclass(eq=False, repr=False)
class Http(betterproto.Message):
    """
    Defines the HTTP configuration for an API service. It contains a list of
    [HttpRule][google.api.HttpRule], each specifying the mapping of an RPC method
    to one or more HTTP REST API methods.
    """

    rules: List["HttpRule"] = betterproto.message_field(1)
    """
    A list of HTTP configuration rules that apply to individual API methods.
    
    **NOTE:** All service configuration rules follow "last one wins" order.
    """

    fully_decode_reserved_expansion: bool = betterproto.bool_field(2)
    """
    When set to true, URL path parameters will be fully URI-decoded except in
    cases of single segment matches in reserved expansion, where "%2F" will be
    left encoded.
    
    The default behavior is to not decode RFC 6570 reserved characters in multi
    segment matches.
    """


@dataclass(eq=False, repr=False)
class HttpRule(betterproto.Message):
    """
    # gRPC Transcoding

    gRPC Transcoding is a feature for mapping between a gRPC method and one or
    more HTTP REST endpoints. It allows developers to build a single API service
    that supports both gRPC APIs and REST APIs. Many systems, including [Google
    APIs](https://github.com/googleapis/googleapis),
    [Cloud Endpoints](https://cloud.google.com/endpoints), [gRPC
    Gateway](https://github.com/grpc-ecosystem/grpc-gateway),
    and [Envoy](https://github.com/envoyproxy/envoy) proxy support this feature
    and use it for large scale production services.

    `HttpRule` defines the schema of the gRPC/REST mapping. The mapping specifies
    how different portions of the gRPC request message are mapped to the URL
    path, URL query parameters, and HTTP request body. It also controls how the
    gRPC response message is mapped to the HTTP response body. `HttpRule` is
    typically specified as an `google.api.http` annotation on the gRPC method.

    Each mapping specifies a URL path template and an HTTP method. The path
    template may refer to one or more fields in the gRPC request message, as long
    as each field is a non-repeated field with a primitive (non-message) type.
    The path template controls how fields of the request message are mapped to
    the URL path.

    Example:

        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http) = {
                get: "/v1/{name=messages/*}"
            };
          }
        }
        message GetMessageRequest {
          string name = 1; // Mapped to URL path.
        }
        message Message {
          string text = 1; // The resource content.
        }

    This enables an HTTP REST to gRPC mapping as below:

    HTTP | gRPC
    -----|-----
    `GET /v1/messages/123456`  | `GetMessage(name: "messages/123456")`

    Any fields in the request message which are not bound by the path template
    automatically become HTTP query parameters if there is no HTTP request body.
    For example:

        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http) = {
                get:"/v1/messages/{message_id}"
            };
          }
        }
        message GetMessageRequest {
          message SubMessage {
            string subfield = 1;
          }
          string message_id = 1; // Mapped to URL path.
          int64 revision = 2;    // Mapped to URL query parameter `revision`.
          SubMessage sub = 3;    // Mapped to URL query parameter `sub.subfield`.
        }

    This enables a HTTP JSON to RPC mapping as below:

    HTTP | gRPC
    -----|-----
    `GET /v1/messages/123456?revision=2&sub.subfield=foo` |
    `GetMessage(message_id: "123456" revision: 2 sub: SubMessage(subfield:
    "foo"))`

    Note that fields which are mapped to URL query parameters must have a
    primitive type or a repeated primitive type or a non-repeated message type.
    In the case of a repeated type, the parameter can be repeated in the URL
    as `...?param=A&param=B`. In the case of a message type, each field of the
    message is mapped to a separate parameter, such as
    `...?foo.a=A&foo.b=B&foo.c=C`.

    For HTTP methods that allow a request body, the `body` field
    specifies the mapping. Consider a REST update method on the
    message resource collection:

        service Messaging {
          rpc UpdateMessage(UpdateMessageRequest) returns (Message) {
            option (google.api.http) = {
              patch: "/v1/messages/{message_id}"
              body: "message"
            };
          }
        }
        message UpdateMessageRequest {
          string message_id = 1; // mapped to the URL
          Message message = 2;   // mapped to the body
        }

    The following HTTP JSON to RPC mapping is enabled, where the
    representation of the JSON in the request body is determined by
    protos JSON encoding:

    HTTP | gRPC
    -----|-----
    `PATCH /v1/messages/123456 { "text": "Hi!" }` | `UpdateMessage(message_id:
    "123456" message { text: "Hi!" })`

    The special name `*` can be used in the body mapping to define that
    every field not bound by the path template should be mapped to the
    request body.  This enables the following alternative definition of
    the update method:

        service Messaging {
          rpc UpdateMessage(Message) returns (Message) {
            option (google.api.http) = {
              patch: "/v1/messages/{message_id}"
              body: "*"
            };
          }
        }
        message Message {
          string message_id = 1;
          string text = 2;
        }

    The following HTTP JSON to RPC mapping is enabled:

    HTTP | gRPC
    -----|-----
    `PATCH /v1/messages/123456 { "text": "Hi!" }` | `UpdateMessage(message_id:
    "123456" text: "Hi!")`

    Note that when using `*` in the body mapping, it is not possible to
    have HTTP parameters, as all fields not bound by the path end in
    the body. This makes this option more rarely used in practice when
    defining REST APIs. The common usage of `*` is in custom methods
    which don't use the URL at all for transferring data.

    It is possible to define multiple HTTP methods for one RPC by using
    the `additional_bindings` option. Example:

        service Messaging {
          rpc GetMessage(GetMessageRequest) returns (Message) {
            option (google.api.http) = {
              get: "/v1/messages/{message_id}"
              additional_bindings {
                get: "/v1/users/{user_id}/messages/{message_id}"
              }
            };
          }
        }
        message GetMessageRequest {
          string message_id = 1;
          string user_id = 2;
        }

    This enables the following two alternative HTTP JSON to RPC mappings:

    HTTP | gRPC
    -----|-----
    `GET /v1/messages/123456` | `GetMessage(message_id: "123456")`
    `GET /v1/users/me/messages/123456` | `GetMessage(user_id: "me" message_id:
    "123456")`

    ## Rules for HTTP mapping

    1. Leaf request fields (recursive expansion nested messages in the request
       message) are classified into three categories:
       - Fields referred by the path template. They are passed via the URL path.
       - Fields referred by the [HttpRule.body][google.api.HttpRule.body]. They
       are passed via the HTTP
         request body.
       - All other fields are passed via the URL query parameters, and the
         parameter name is the field path in the request message. A repeated
         field can be represented as multiple query parameters under the same
         name.
     2. If [HttpRule.body][google.api.HttpRule.body] is "*", there is no URL
     query parameter, all fields
        are passed via URL path and HTTP request body.
     3. If [HttpRule.body][google.api.HttpRule.body] is omitted, there is no HTTP
     request body, all
        fields are passed via URL path and URL query parameters.

    ### Path template syntax

        Template = "/" Segments [ Verb ] ;
        Segments = Segment { "/" Segment } ;
        Segment  = "*" | "**" | LITERAL | Variable ;
        Variable = "{" FieldPath [ "=" Segments ] "}" ;
        FieldPath = IDENT { "." IDENT } ;
        Verb     = ":" LITERAL ;

    The syntax `*` matches a single URL path segment. The syntax `**` matches
    zero or more URL path segments, which must be the last part of the URL path
    except the `Verb`.

    The syntax `Variable` matches part of the URL path as specified by its
    template. A variable template must not contain other variables. If a variable
    matches a single path segment, its template may be omitted, e.g. `{var}`
    is equivalent to `{var=*}`.

    The syntax `LITERAL` matches literal text in the URL path. If the `LITERAL`
    contains any reserved character, such characters should be percent-encoded
    before the matching.

    If a variable contains exactly one path segment, such as `"{var}"` or
    `"{var=*}"`, when such a variable is expanded into a URL path on the client
    side, all characters except `[-_.~0-9a-zA-Z]` are percent-encoded. The
    server side does the reverse decoding. Such variables show up in the
    [Discovery
    Document](https://developers.google.com/discovery/v1/reference/apis) as
    `{var}`.

    If a variable contains multiple path segments, such as `"{var=foo/*}"`
    or `"{var=**}"`, when such a variable is expanded into a URL path on the
    client side, all characters except `[-_.~/0-9a-zA-Z]` are percent-encoded.
    The server side does the reverse decoding, except "%2F" and "%2f" are left
    unchanged. Such variables show up in the
    [Discovery
    Document](https://developers.google.com/discovery/v1/reference/apis) as
    `{+var}`.

    ## Using gRPC API Service Configuration

    gRPC API Service Configuration (service config) is a configuration language
    for configuring a gRPC service to become a user-facing product. The
    service config is simply the YAML representation of the `google.api.Service`
    proto message.

    As an alternative to annotating your proto file, you can configure gRPC
    transcoding in your service config YAML files. You do this by specifying a
    `HttpRule` that maps the gRPC method to a REST endpoint, achieving the same
    effect as the proto annotation. This can be particularly useful if you
    have a proto that is reused in multiple services. Note that any transcoding
    specified in the service config will override any matching transcoding
    configuration in the proto.

    Example:

        http:
          rules:
            # Selects a gRPC method and applies HttpRule to it.
            - selector: example.v1.Messaging.GetMessage
              get: /v1/messages/{message_id}/{sub.subfield}

    ## Special notes

    When gRPC Transcoding is used to map a gRPC to JSON REST endpoints, the
    proto to JSON conversion must follow the [proto3
    specification](https://developers.google.com/protocol-buffers/docs/proto3#json).

    While the single segment variable follows the semantics of
    [RFC 6570](https://tools.ietf.org/html/rfc6570) Section 3.2.2 Simple String
    Expansion, the multi segment variable **does not** follow RFC 6570 Section
    3.2.3 Reserved Expansion. The reason is that the Reserved Expansion
    does not expand special characters like `?` and `#`, which would lead
    to invalid URLs. As the result, gRPC Transcoding uses a custom encoding
    for multi segment variables.

    The path variables **must not** refer to any repeated or mapped field,
    because client libraries are not capable of handling such variable expansion.

    The path variables **must not** capture the leading "/" character. The reason
    is that the most common use case "{var}" does not capture the leading "/"
    character. For consistency, all path variables must share the same behavior.

    Repeated message fields must not be mapped to URL query parameters, because
    no client library can support such complicated mapping.

    If an API needs to use a JSON array for request or response body, it can map
    the request or response body to a repeated field. However, some gRPC
    Transcoding implementations may not support this feature.
    """

    selector: str = betterproto.string_field(1)
    """
    Selects a method to which this rule applies.
    
    Refer to [selector][google.api.DocumentationRule.selector] for syntax
    details.
    """

    get: str = betterproto.string_field(2, group="pattern")
    """
    Maps to HTTP GET. Used for listing and getting information about
    resources.
    """

    put: str = betterproto.string_field(3, group="pattern")
    """Maps to HTTP PUT. Used for replacing a resource."""

    post: str = betterproto.string_field(4, group="pattern")
    """
    Maps to HTTP POST. Used for creating a resource or performing an action.
    """

    delete: str = betterproto.string_field(5, group="pattern")
    """Maps to HTTP DELETE. Used for deleting a resource."""

    patch: str = betterproto.string_field(6, group="pattern")
    """Maps to HTTP PATCH. Used for updating a resource."""

    custom: "CustomHttpPattern" = betterproto.message_field(8, group="pattern")
    """
    The custom pattern is used for specifying an HTTP method that is not
    included in the `pattern` field, such as HEAD, or "*" to leave the
    HTTP method unspecified for this rule. The wild-card rule is useful
    for services that provide content to Web (HTML) clients.
    """

    body: str = betterproto.string_field(7)
    """
    The name of the request field whose value is mapped to the HTTP request
    body, or `*` for mapping all request fields not captured by the path
    pattern to the HTTP body, or omitted for not having any HTTP request body.
    
    NOTE: the referred field must be present at the top-level of the request
    message type.
    """

    response_body: str = betterproto.string_field(12)
    """
    Optional. The name of the response field whose value is mapped to the HTTP
    response body. When omitted, the entire response message will be used
    as the HTTP response body.
    
    NOTE: The referred field must be present at the top-level of the response
    message type.
    """

    additional_bindings: List["HttpRule"] = betterproto.message_field(11)
    """
    Additional HTTP bindings for the selector. Nested bindings must
    not contain an `additional_bindings` field themselves (that is,
    the nesting may only be one level deep).
    """


@dataclass(eq=False, repr=False)
class CustomHttpPattern(betterproto.Message):
    """A custom pattern is used for defining custom HTTP verb."""

    kind: str = betterproto.string_field(1)
    """The name of this custom HTTP verb."""

    path: str = betterproto.string_field(2)
    """The path matched by this custom verb."""



from . import deployment_pb2 as _deployment_pb2
from . import options_pb2 as _options_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeploymentTemplate(_message.Message):
    __slots__ = ("name", "display_name", "description", "create_time", "created_by", "min_replica_count", "max_replica_count", "autoscaling_policy", "base_model", "accelerator_count", "accelerator_type", "world_size", "generator_count", "disaggregated_prefill_count", "disaggregated_prefill_world_size", "max_batch_size", "max_peft_batch_size", "kv_cache_memory_pct", "enable_addons", "draft_model", "ngram_speculation_length", "draft_token_count", "enable_session_affinity", "image_tag", "region", "direct_route_api_keys", "direct_route_type", "precision", "extra_args", "extra_values", "update_time", "max_context_length")
    class ExtraValuesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    MIN_REPLICA_COUNT_FIELD_NUMBER: _ClassVar[int]
    MAX_REPLICA_COUNT_FIELD_NUMBER: _ClassVar[int]
    AUTOSCALING_POLICY_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    ACCELERATOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    WORLD_SIZE_FIELD_NUMBER: _ClassVar[int]
    GENERATOR_COUNT_FIELD_NUMBER: _ClassVar[int]
    DISAGGREGATED_PREFILL_COUNT_FIELD_NUMBER: _ClassVar[int]
    DISAGGREGATED_PREFILL_WORLD_SIZE_FIELD_NUMBER: _ClassVar[int]
    MAX_BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    MAX_PEFT_BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    KV_CACHE_MEMORY_PCT_FIELD_NUMBER: _ClassVar[int]
    ENABLE_ADDONS_FIELD_NUMBER: _ClassVar[int]
    DRAFT_MODEL_FIELD_NUMBER: _ClassVar[int]
    NGRAM_SPECULATION_LENGTH_FIELD_NUMBER: _ClassVar[int]
    DRAFT_TOKEN_COUNT_FIELD_NUMBER: _ClassVar[int]
    ENABLE_SESSION_AFFINITY_FIELD_NUMBER: _ClassVar[int]
    IMAGE_TAG_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    DIRECT_ROUTE_API_KEYS_FIELD_NUMBER: _ClassVar[int]
    DIRECT_ROUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    EXTRA_ARGS_FIELD_NUMBER: _ClassVar[int]
    EXTRA_VALUES_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEXT_LENGTH_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    description: str
    create_time: _timestamp_pb2.Timestamp
    created_by: str
    min_replica_count: int
    max_replica_count: int
    autoscaling_policy: _deployment_pb2.AutoscalingPolicy
    base_model: str
    accelerator_count: int
    accelerator_type: _deployment_pb2.AcceleratorType
    world_size: int
    generator_count: int
    disaggregated_prefill_count: int
    disaggregated_prefill_world_size: int
    max_batch_size: int
    max_peft_batch_size: int
    kv_cache_memory_pct: int
    enable_addons: bool
    draft_model: str
    ngram_speculation_length: int
    draft_token_count: int
    enable_session_affinity: bool
    image_tag: str
    region: _deployment_pb2.Region
    direct_route_api_keys: _containers.RepeatedScalarFieldContainer[str]
    direct_route_type: _deployment_pb2.DirectRouteType
    precision: _deployment_pb2.Deployment.Precision
    extra_args: _containers.RepeatedScalarFieldContainer[str]
    extra_values: _containers.ScalarMap[str, str]
    update_time: _timestamp_pb2.Timestamp
    max_context_length: int
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., min_replica_count: _Optional[int] = ..., max_replica_count: _Optional[int] = ..., autoscaling_policy: _Optional[_Union[_deployment_pb2.AutoscalingPolicy, _Mapping]] = ..., base_model: _Optional[str] = ..., accelerator_count: _Optional[int] = ..., accelerator_type: _Optional[_Union[_deployment_pb2.AcceleratorType, str]] = ..., world_size: _Optional[int] = ..., generator_count: _Optional[int] = ..., disaggregated_prefill_count: _Optional[int] = ..., disaggregated_prefill_world_size: _Optional[int] = ..., max_batch_size: _Optional[int] = ..., max_peft_batch_size: _Optional[int] = ..., kv_cache_memory_pct: _Optional[int] = ..., enable_addons: bool = ..., draft_model: _Optional[str] = ..., ngram_speculation_length: _Optional[int] = ..., draft_token_count: _Optional[int] = ..., enable_session_affinity: bool = ..., image_tag: _Optional[str] = ..., region: _Optional[_Union[_deployment_pb2.Region, str]] = ..., direct_route_api_keys: _Optional[_Iterable[str]] = ..., direct_route_type: _Optional[_Union[_deployment_pb2.DirectRouteType, str]] = ..., precision: _Optional[_Union[_deployment_pb2.Deployment.Precision, str]] = ..., extra_args: _Optional[_Iterable[str]] = ..., extra_values: _Optional[_Mapping[str, str]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_context_length: _Optional[int] = ...) -> None: ...

class CreateDeploymentTemplateRequest(_message.Message):
    __slots__ = ("parent", "deployment_template", "deployment_template_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    deployment_template: DeploymentTemplate
    deployment_template_id: str
    def __init__(self, parent: _Optional[str] = ..., deployment_template: _Optional[_Union[DeploymentTemplate, _Mapping]] = ..., deployment_template_id: _Optional[str] = ...) -> None: ...

class GetDeploymentTemplateRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListDeploymentTemplatesRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListDeploymentTemplatesResponse(_message.Message):
    __slots__ = ("deployment_templates", "next_page_token", "total_size")
    DEPLOYMENT_TEMPLATES_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    deployment_templates: _containers.RepeatedCompositeFieldContainer[DeploymentTemplate]
    next_page_token: str
    total_size: int
    def __init__(self, deployment_templates: _Optional[_Iterable[_Union[DeploymentTemplate, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateDeploymentTemplateRequest(_message.Message):
    __slots__ = ("deployment_template", "update_mask")
    DEPLOYMENT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    deployment_template: DeploymentTemplate
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, deployment_template: _Optional[_Union[DeploymentTemplate, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteDeploymentTemplateRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Money(_message.Message):
    __slots__ = ("currency_code", "units", "nanos")
    CURRENCY_CODE_FIELD_NUMBER: _ClassVar[int]
    UNITS_FIELD_NUMBER: _ClassVar[int]
    NANOS_FIELD_NUMBER: _ClassVar[int]
    currency_code: str
    units: int
    nanos: int
    def __init__(self, currency_code: _Optional[str] = ..., units: _Optional[int] = ..., nanos: _Optional[int] = ...) -> None: ...



from enum import Enum
from typing import List, Mapping, Optional, Union
from pydantic import BaseModel, Field


class Error(BaseModel, extra="forbid"):
    object: str = "error"
    type: str = "invalid_request_error"
    message: str


class ErrorResponse(BaseModel, extra="forbid"):
    error: Error = Field(default_factory=Error)


class TranscriptionRequest(BaseModel):
    model: Optional[str] = None
    vad_model: Optional[str] = None
    alignment_model: Optional[str] = None
    diarization_model: Optional[str] = None
    skip_vad: Optional[bool] = None

    prompt: Optional[str] = None
    response_format: Optional[str] = None
    temperature: Optional[Union[float, List[float]]] = None
    preprocessing: Optional[str] = None
    max_clip_len: Optional[float] = None

    language: Optional[str] = None
    timestamp_granularities: Optional[List[str]] = None
    diarize: Optional[str] = None
    min_speakers: Optional[int] = None
    max_speakers: Optional[int] = None

    def to_multipart(self) -> Mapping[str, Union[str, bytes]]:
        result = {}
        for key, value in self.model_dump(exclude_none=True).items():
            if isinstance(value, (str, bytes)):
                result[key] = value
            elif isinstance(value, list):
                result[key] = ",".join(str(e) for e in value)
            else:
                result[key] = str(value)
        return result


class TranscriptionResponse(BaseModel):
    text: str


class TranscriptionWord(BaseModel):
    word: str
    start: Optional[float]
    end: Optional[float]
    language: str
    probability: Optional[float] = None
    hallucination_score: Optional[float] = 0.0
    is_final: Optional[bool] = None
    speaker_id: Optional[str] = None


class TranscriptionSegment(BaseModel):
    id: int
    seek: int
    start: Optional[float]
    end: Optional[float]
    audio_start: Optional[float]
    audio_end: Optional[float]
    text: str
    language: str
    tokens: List[int]
    words: Optional[List[TranscriptionWord]] = None
    temperature: Optional[float] = None
    avg_logprob: Optional[float] = None
    compression_ratio: Optional[float] = None
    no_speech_prob: Optional[float] = None
    no_speech: Optional[bool] = None
    retry_count: Optional[int] = None
    speaker_id: Optional[str] = None


class TranscriptionVerboseResponse(BaseModel):
    task: str = "transcribe"  # Not documented by returned by OAI API
    language: str
    duration: Optional[float]
    text: str
    words: Optional[List[TranscriptionWord]] = None
    segments: Optional[List[TranscriptionSegment]] = None


class TranslationRequest(BaseModel):
    model: Optional[str] = None
    vad_model: Optional[str] = None
    alignment_model: Optional[str] = None
    skip_vad: Optional[bool] = None

    prompt: Optional[str] = None
    response_format: Optional[str] = None
    temperature: Optional[Union[float, List[float]]] = None
    preprocessing: Optional[str] = None
    max_clip_len: Optional[float] = None

    timestamp_granularities: Optional[List[str]] = None

    def to_multipart(self) -> Mapping[str, Union[str, bytes]]:
        result = {}
        for key, value in self.model_dump(exclude_none=True).items():
            if isinstance(value, (str, bytes)):
                result[key] = value
            elif isinstance(value, list):
                result[key] = ",".join(str(e) for e in value)
            else:
                result[key] = str(value)
        return result


class AlignmentRequest(BaseModel):
    vad_model: Optional[str] = None
    alignment_model: Optional[str] = None

    text: str
    response_format: Optional[str] = None
    preprocessing: Optional[str] = None

    def to_multipart(self) -> Mapping[str, Union[str, bytes]]:
        result = {}
        for key, value in self.model_dump(exclude_none=True).items():
            if isinstance(value, (str, bytes)):
                result[key] = value
            elif isinstance(value, list):
                result[key] = ",".join(str(e) for e in value)
            else:
                result[key] = str(value)
        return result